import { Backend, Options } from '@sentry/core';
import { SentryEvent, SentryResponse } from '@sentry/types';
/**
 * Configuration options for the Sentry Node SDK.
 * @see NodeClient for more information.
 */
export interface NodeOptions extends Options {
    /** Callback that is executed when a fatal global error occurs. */
    onFatalError?(error: Error): void;
}
/** The Sentry Node SDK Backend. */
export declare class NodeBackend implements Backend {
    private readonly options;
    /** Creates a new Node backend instance. */
    constructor(options?: NodeOptions);
    /**
     * @inheritDoc
     */
    eventFromException(exception: any): Promise<SentryEvent>;
    /**
     * @inheritDoc
     */
    eventFromMessage(message: string): Promise<SentryEvent>;
    /**
     * @inheritDoc
     */
    sendEvent(event: SentryEvent): Promise<SentryResponse>;
    /**
     * @inheritDoc
     */
    storeBreadcrumb(): boolean;
    /**
     * @inheritDoc
     */
    storeScope(): void;
}
