"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@sentry/core");
var hub_1 = require("@sentry/hub");
var is_1 = require("@sentry/utils/is");
var object_1 = require("@sentry/utils/object");
var md5 = require("md5");
var stacktrace = require("stack-trace");
var parsers_1 = require("./parsers");
var transports_1 = require("./transports");
/** The Sentry Node SDK Backend. */
var NodeBackend = /** @class */ (function () {
    /** Creates a new Node backend instance. */
    function NodeBackend(options) {
        if (options === void 0) { options = {}; }
        this.options = options;
    }
    /**
     * @inheritDoc
     */
    NodeBackend.prototype.eventFromException = function (exception) {
        return __awaiter(this, void 0, void 0, function () {
            var stack, ex, keys_1, message, event, _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        ex = exception;
                        if (!is_1.isError(exception)) {
                            if (is_1.isPlainObject(exception)) {
                                keys_1 = Object.keys(exception).sort();
                                message = "Non-Error exception captured with keys: " + object_1.serializeKeysToEventMessage(keys_1);
                                // TODO: We also set `event.message` here previously, check if it works without it as well
                                hub_1.getDefaultHub().configureScope(function (scope) {
                                    scope.setExtra('__serialized__', object_1.limitObjectDepthToSize(exception));
                                    scope.setFingerprint([md5(keys_1.join(''))]);
                                });
                                ex = new Error(message);
                            }
                            else {
                                // This handles when someone does: `throw "something awesome";`
                                // We synthesize an Error here so we can extract a (rough) stack trace.
                                ex = new Error(exception);
                            }
                            stack = stacktrace.get();
                        }
                        if (!stack) return [3 /*break*/, 2];
                        return [4 /*yield*/, parsers_1.parseError(ex, stack)];
                    case 1:
                        _a = _b.sent();
                        return [3 /*break*/, 4];
                    case 2: return [4 /*yield*/, parsers_1.parseError(ex)];
                    case 3:
                        _a = _b.sent();
                        _b.label = 4;
                    case 4:
                        event = _a;
                        return [2 /*return*/, event];
                }
            });
        });
    };
    /**
     * @inheritDoc
     */
    NodeBackend.prototype.eventFromMessage = function (message) {
        return __awaiter(this, void 0, void 0, function () {
            var stack, frames, event;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        stack = stacktrace.get();
                        return [4 /*yield*/, parsers_1.parseStack(stack)];
                    case 1:
                        frames = _a.sent();
                        event = {
                            message: message,
                            stacktrace: {
                                frames: parsers_1.prepareFramesForEvent(frames),
                            },
                        };
                        return [2 /*return*/, event];
                }
            });
        });
    };
    /**
     * @inheritDoc
     */
    NodeBackend.prototype.sendEvent = function (event) {
        return __awaiter(this, void 0, void 0, function () {
            var dsn, transportOptions, transport;
            return __generator(this, function (_a) {
                if (!this.options.dsn) {
                    throw new core_1.SentryError('Cannot sendEvent without a valid DSN');
                }
                else {
                    dsn = new core_1.DSN(this.options.dsn);
                }
                transportOptions = this.options.transportOptions ? this.options.transportOptions : { dsn: dsn };
                transport = this.options.transport
                    ? new this.options.transport({ dsn: dsn })
                    : dsn.protocol === 'http'
                        ? new transports_1.HTTPTransport(transportOptions)
                        : new transports_1.HTTPSTransport(transportOptions);
                return [2 /*return*/, transport.send(event)];
            });
        });
    };
    /**
     * @inheritDoc
     */
    NodeBackend.prototype.storeBreadcrumb = function () {
        return true;
    };
    /**
     * @inheritDoc
     */
    NodeBackend.prototype.storeScope = function () {
        // Noop
    };
    return NodeBackend;
}());
exports.NodeBackend = NodeBackend;
//# sourceMappingURL=backend.js.map